@@ -6,6 +6,10 @@
 import sys, os, skytools
 from installer import *
 
+# support set() on 2.3
+if 'set' not in dir(__builtins__):
+    from sets import Set as set
+
 __all__ = ['ProviderSetup', 'SubscriberSetup']
 
 def find_column_types(curs, table):
